@@ -18,6 +18,7 @@
 
 #include <bakery/App/App_Gtk.h>
 #include <gtkmm/stock.h>
+#include <gtkmm/aboutdialog.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/toolbutton.h>
 #include <libintl.h>
@@ -323,19 +324,15 @@ void App_Gtk::on_menu_help_about()
       m_pAbout = 0;
     }
 
-    m_pAbout = new Gtk::MessageDialog(*this,
-      gettext("Application: ") + m_strAppName + "\n" +
-      gettext("Copyright: ") + m_HelpInfo.m_strCopyright + "\n" );
+    Gtk::AboutDialog* pDerived = new Gtk::AboutDialog;
+    m_pAbout = pDerived;
 
-    //TODO: Authors and Translators.
-    
-    /*
-    m_pAbout = new Gnome::UI::About(m_strAppName, m_HelpInfo.m_strVersion,
-                               m_HelpInfo.m_strCopyright,
-                               m_HelpInfo.m_vecAuthors, m_HelpInfo.m_vecDocumenters,
-                               m_HelpInfo.m_strDescription, m_HelpInfo.m_strTranslatorCredits,
-                               refLogo);
-    */
+    pDerived->set_name(m_strAppName);
+    pDerived->set_version(m_HelpInfo.m_strVersion);
+    pDerived->set_copyright(m_HelpInfo.m_strCopyright);
+    pDerived->set_authors(m_HelpInfo.m_vecAuthors);
+    pDerived->set_documenters(m_HelpInfo.m_vecDocumenters);
+    pDerived->set_translator_credits(m_HelpInfo.m_strTranslatorCredits);
 
     m_pAbout->signal_hide().connect(sigc::mem_fun((App&)*this, &App::on_about_close));
     m_bAboutShown = true;
@@ -350,6 +347,11 @@ void App_Gtk::on_about_close()
   m_bAboutShown = false;
 }
 
+Glib::ustring App_Gtk::util_bold_message(const Glib::ustring& message)
+{
+  return "<b>" + message + "</b>";
+}
+
 
 
 } //namespace
