@@ -69,7 +69,9 @@ public:
     SAVECHANGES_Cancel,
     SAVECHANGES_Discard
   };
- 
+
+  static bool file_exists(const Glib::ustring& uri);
+
 protected:
   virtual void init_create_document(); //override this to new() the specific document type.
 
@@ -84,9 +86,9 @@ protected:
 
   ///static_cast<> or dynamic_cast<> this pointer to the correct type.
   virtual const Document* get_document() const ;
-  
+
   virtual void set_document_modified(bool bModified = true);
-  
+
   ///bool indicates success.
   virtual bool open_document(const Glib::ustring& file_uri);
 
@@ -107,46 +109,43 @@ public: // We can not take function pointers of these methods in a
   virtual void on_menu_edit_copy();
   virtual void on_menu_edit_paste();
   virtual void on_menu_edit_clear();
-  
+
 protected:
   //Document:
   ///Update visual status.
   virtual void on_document_modified(bool modified);
-  
+
   ///override this to show document contents.
   virtual bool on_document_load();
 
 
   virtual void offer_to_save_changes();
-  
+
   ///Stop the File|Close or the File|Exit.
   virtual void cancel_close_or_exit();
-  
+
   ///destroy it or mark it for destruction.
   virtual void close_mark_or_destroy();
-  
+
   virtual void update_window_title();
- 
+
   virtual void after_successful_save(); //e.g. disable File|Save.
 
-  virtual void ui_warning(const Glib::ustring& text) = 0;
-  virtual Glib::ustring ui_file_select_open() = 0;
+  virtual void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text) = 0;
+  virtual Glib::ustring ui_file_select_open(const Glib::ustring& ui_file_select_open = Glib::ustring()) = 0;
 
   /** Present a user interface that allows the user to select a location to save the file.
    * @param old_file_uri The existing URI of the file, if any.
    * @result The URI of the file chosen by the user.
    */
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri) = 0;
-  
+
   virtual void ui_show_modification_status() = 0;
 
   virtual enumSaveChanges ui_offer_to_save_changes() = 0;
 
-  virtual bool ui_ask_overwrite(const std::string& file_uri) = 0;
-  
   static Glib::ustring get_conf_fullkey(const Glib::ustring& key);
 
-
   //Document:
   Document* m_pDocument; //An instance of a derived type.
   bool m_bCloseAfterSave;
