@@ -61,22 +61,20 @@ protected:
   virtual void init_menus_file(); //overridden to add open/save/save as.
   virtual void init_menus_file_recentfiles(const Glib::ustring& path); // call this in init_menus_file()
   virtual void init_toolbars(); //overridden to add open/save
-  
+
   virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
   virtual void document_history_remove(const Glib::ustring& file_uri); //overridden.
 
   virtual void update_window_title();
 
-  virtual void ui_warning(const Glib::ustring& text);
-  virtual Glib::ustring ui_file_select_open();
+  virtual void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text);
+  virtual Glib::ustring ui_file_select_open(const Glib::ustring& starting_folder_uri = Glib::ustring());
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri);
   virtual void ui_show_modification_status();
   virtual enumSaveChanges ui_offer_to_save_changes();
-  virtual bool ui_ask_overwrite(const std::string& file_uri);
-
 
   void on_recent_files_activate(EggRecentItem* item);
-  
+
   //Menu stuff:
   Glib::RefPtr<Gtk::Action> m_action_save, m_action_saveas;
   EggRecentModel* m_recent_files_model;
