@@ -20,8 +20,6 @@
 #define DIALOG_OFFERSAVE_H
 
 #include <gtkmm/messagedialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/box.h>
 
 namespace Bakery
 {
@@ -29,7 +27,7 @@ namespace Bakery
 class Dialog_OfferSave : public Gtk::MessageDialog
 {
 public:
-  Dialog_OfferSave(const Glib::ustring& filepath);
+  Dialog_OfferSave(const Glib::ustring& file_uri);
   virtual ~Dialog_OfferSave();
 
   ///Return values:
