@@ -22,7 +22,7 @@
 #ifndef HEADER_VIEW_EXAMPLE
 #define HEADER_VIEW_EXAMPLE
 
-#include <gtk--/box.h>
+#include <gtkmm/box.h>
 #include "docexample.h"
 
 class ViewExample : 
